@@ -41,8 +41,10 @@ except ImportError:
     # Python 3.x
     import configparser as ConfigParser
 
+import toml
 
-__version__ = '0.37'
+
+__version__ = '0.40'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'MIT'
 __url__ = 'https://github.com/mgedmin/check-manifest'
@@ -281,6 +283,9 @@ def strip_toplevel_name(filelist):
         >>> strip_toplevel_name(['a', 'a/b', 'a/c', 'a/c/d'])
         ['b', 'c', 'c/d']
 
+        >>> strip_toplevel_name(['a', 'a/', 'a/b', 'a/c', 'a/c/d'])
+        ['b', 'c', 'c/d']
+
         >>> strip_toplevel_name(['a/b', 'a/c', 'a/c/d'])
         ['b', 'c', 'c/d']
 
@@ -298,7 +303,7 @@ def strip_toplevel_name(filelist):
         if not name.startswith(prefix):
             raise Failure("File doesn't have the common prefix (%s): %s"
                           % (name, prefix))
-    return [name[len(prefix):] for name in names]
+    return [name[len(prefix):] for name in names if name != prefix]
 
 
 def add_prefix_to_each(prefix, filelist):
@@ -529,6 +534,8 @@ IGNORE = [
     # it's not a problem if the sdist is lacking these files:
     '.hgtags', '.hgsigs', '.hgignore', '.gitignore', '.bzrignore',
     '.gitattributes',
+    '.github',      # GitHub template files
+    '.github/*',    # GitHub template files
     '.travis.yml',
     'Jenkinsfile',
     # it's convenient to ship compiled .mo files in sdists, but they shouldn't
@@ -587,22 +594,59 @@ CFG_IGNORE_BAD_IDEAS = (CFG_SECTION_CHECK_MANIFEST, 'ignore-bad-ideas')
 
 
 def read_config():
-    """Read configuration from setup.cfg."""
+    """Read configuration from file if possible."""
     # XXX modifies global state, which is kind of evil
-    config = ConfigParser.ConfigParser()
-    config.read(['setup.cfg'])
-    if not config.has_section(CFG_SECTION_CHECK_MANIFEST):
-        return
-    if (config.has_option(*CFG_IGNORE_DEFAULT_RULES)
-            and config.getboolean(*CFG_IGNORE_DEFAULT_RULES)):
+    config = _load_config()
+    if config.get(CFG_IGNORE_DEFAULT_RULES[1], False):
         del IGNORE[:]
-    if config.has_option(*CFG_IGNORE):
-        patterns = [p.strip() for p in config.get(*CFG_IGNORE).splitlines()]
-        IGNORE.extend(p for p in patterns if p)
-    if config.has_option(*CFG_IGNORE_BAD_IDEAS):
-        lines = config.get(*CFG_IGNORE_BAD_IDEAS).splitlines()
-        patterns = [p.strip() for p in lines]
-        IGNORE_BAD_IDEAS.extend(p for p in patterns if p)
+    if CFG_IGNORE[1] in config:
+        IGNORE.extend(p for p in config[CFG_IGNORE[1]] if p)
+    if CFG_IGNORE_BAD_IDEAS[1] in config:
+        IGNORE_BAD_IDEAS.extend(p for p in config[CFG_IGNORE_BAD_IDEAS[1]] if p)
+
+
+def _load_config():
+    """Searches for config files, reads them and returns a dictionary
+
+    Looks for a ``check-manifest`` section in ``pyproject.toml``,
+    ``setup.cfg``, and ``tox.ini``, in that order.  The first file
+    that exists and has that section will be loaded and returned as a
+    dictionary.
+
+    """
+    if os.path.exists("pyproject.toml"):
+        config = toml.load("pyproject.toml")
+        if CFG_SECTION_CHECK_MANIFEST in config.get("tool", {}):
+            return config["tool"][CFG_SECTION_CHECK_MANIFEST]
+
+    search_files = ['setup.cfg', 'tox.ini']
+    config_parser = ConfigParser.ConfigParser()
+    for filename in search_files:
+        if (config_parser.read([filename])
+                and config_parser.has_section(CFG_SECTION_CHECK_MANIFEST)):
+            config = {}
+
+            if config_parser.has_option(*CFG_IGNORE_DEFAULT_RULES):
+                ignore_defaults = config_parser.getboolean(*CFG_IGNORE_DEFAULT_RULES)
+                config[CFG_IGNORE_DEFAULT_RULES[1]] = ignore_defaults
+
+            if config_parser.has_option(*CFG_IGNORE):
+                patterns = [
+                    p.strip()
+                    for p in config_parser.get(*CFG_IGNORE).splitlines()
+                ]
+                config[CFG_IGNORE[1]] = patterns
+
+            if config_parser.has_option(*CFG_IGNORE_BAD_IDEAS):
+                patterns = [
+                    p.strip()
+                    for p in config_parser.get(*CFG_IGNORE_BAD_IDEAS).splitlines()
+                ]
+                config[CFG_IGNORE_BAD_IDEAS[1]] = patterns
+
+            return config
+
+    return {}
 
 
 def read_manifest():
@@ -714,8 +758,8 @@ def _get_ignore_from_manifest_lines(lines):
                     # of sub directories.  We could use a regexp, but
                     # two ignores seems easier.
                     ignore.append(dirname + os.path.sep + pattern)
-                    ignore.append(dirname + os.path.sep + '*' + os.path.sep +
-                                  pattern)
+                    ignore.append(
+                        dirname + os.path.sep + '*' + os.path.sep + pattern)
         elif cmd == 'prune':
             # rest is considered to be a directory name.  It should
             # not contain a path separator, as it actually has no
@@ -732,8 +776,8 @@ def _get_ignore_from_manifest_lines(lines):
 
 def file_matches(filename, patterns):
     """Does this filename match any of the patterns?"""
-    return any(fnmatch.fnmatch(filename, pat) or
-               fnmatch.fnmatch(os.path.basename(filename), pat)
+    return any(fnmatch.fnmatch(filename, pat)
+               or fnmatch.fnmatch(os.path.basename(filename), pat)
                for pat in patterns)
 
 
