@@ -1,7 +1,10 @@
+from __future__ import print_function
+
 import codecs
 import doctest
 import locale
 import os
+import shutil
 import subprocess
 import sys
 import tarfile
@@ -287,6 +290,9 @@ class Tests(unittest.TestCase):
     def test_strip_sdist_extras(self):
         from check_manifest import strip_sdist_extras
         filelist = list(map(os.path.normpath, [
+            '.github',
+            '.github/ISSUE_TEMPLATE',
+            '.github/ISSUE_TEMPLATE/bug_report.md',
             '.gitignore',
             '.travis.yml',
             'setup.py',
@@ -329,6 +335,7 @@ class Tests(unittest.TestCase):
             recursive-exclude src/zope *.sh
         """)
         filelist = list(map(os.path.normpath, [
+            '.github/ISSUE_TEMPLATE/bug_report.md',
             '.gitignore',
             'setup.py',
             'setup.cfg',
@@ -614,21 +621,35 @@ class TestConfiguration(unittest.TestCase):
         check_manifest.read_config()
         self.assertEqual(check_manifest.IGNORE, ['default-ignore-rules'])
 
-    def test_read_config_no_section(self):
+    def test_read_setup_config_no_section(self):
         import check_manifest
         with open('setup.cfg', 'w') as f:
             f.write('[pep8]\nignore =\n')
         check_manifest.read_config()
         self.assertEqual(check_manifest.IGNORE, ['default-ignore-rules'])
 
-    def test_read_config_no_option(self):
+    def test_read_pyproject_config_no_section(self):
+        import check_manifest
+        with open('pyproject.toml', 'w') as f:
+            f.write('[tool.pep8]\nignore = []\n')
+        check_manifest.read_config()
+        self.assertEqual(check_manifest.IGNORE, ['default-ignore-rules'])
+
+    def test_read_setup_config_no_option(self):
         import check_manifest
         with open('setup.cfg', 'w') as f:
             f.write('[check-manifest]\n')
         check_manifest.read_config()
         self.assertEqual(check_manifest.IGNORE, ['default-ignore-rules'])
 
-    def test_read_config_extra_ignores(self):
+    def test_read_pyproject_config_no_option(self):
+        import check_manifest
+        with open('pyproject.toml', 'w') as f:
+            f.write('[tool.check-manifest]\n')
+        check_manifest.read_config()
+        self.assertEqual(check_manifest.IGNORE, ['default-ignore-rules'])
+
+    def test_read_setup_config_extra_ignores(self):
         import check_manifest
         with open('setup.cfg', 'w') as f:
             f.write('[check-manifest]\nignore = foo\n  bar\n')
@@ -636,7 +657,15 @@ class TestConfiguration(unittest.TestCase):
         self.assertEqual(check_manifest.IGNORE,
                          ['default-ignore-rules', 'foo', 'bar'])
 
-    def test_read_config_override_ignores(self):
+    def test_read_pyproject_config_extra_ignores(self):
+        import check_manifest
+        with open('pyproject.toml', 'w') as f:
+            f.write('[tool.check-manifest]\nignore = ["foo", "bar"]\n')
+        check_manifest.read_config()
+        self.assertEqual(check_manifest.IGNORE,
+                         ['default-ignore-rules', 'foo', 'bar'])
+
+    def test_read_setup_config_override_ignores(self):
         import check_manifest
         with open('setup.cfg', 'w') as f:
             f.write('[check-manifest]\nignore = foo\n\n  bar\n')
@@ -645,7 +674,16 @@ class TestConfiguration(unittest.TestCase):
         self.assertEqual(check_manifest.IGNORE,
                          ['foo', 'bar'])
 
-    def test_read_config_ignore_bad_ideas(self):
+    def test_read_pyproject_config_override_ignores(self):
+        import check_manifest
+        with open('pyproject.toml', 'w') as f:
+            f.write('[tool.check-manifest]\nignore = ["foo", "bar"]\n')
+            f.write('ignore-default-rules = true\n')
+        check_manifest.read_config()
+        self.assertEqual(check_manifest.IGNORE,
+                         ['foo', 'bar'])
+
+    def test_read_setup_config_ignore_bad_ideas(self):
         import check_manifest
         with open('setup.cfg', 'w') as f:
             f.write('[check-manifest]\n'
@@ -655,6 +693,14 @@ class TestConfiguration(unittest.TestCase):
         check_manifest.read_config()
         self.assertEqual(check_manifest.IGNORE_BAD_IDEAS, ['foo', 'bar'])
 
+    def test_read_pyproject_config_ignore_bad_ideas(self):
+        import check_manifest
+        with open('pyproject.toml', 'w') as f:
+            f.write('[tool.check-manifest]\n'
+                    'ignore-bad-ideas = ["foo", "bar"]\n')
+        check_manifest.read_config()
+        self.assertEqual(check_manifest.IGNORE_BAD_IDEAS, ['foo', 'bar'])
+
     def test_read_manifest_no_manifest(self):
         import check_manifest
         check_manifest.read_manifest()
@@ -843,13 +889,17 @@ class VCSHelper(object):
         # https://github.com/mgedmin/check-manifest/issues/23#issuecomment-33933031
         if str is bytes:
             command = [s.encode(locale.getpreferredencoding()) for s in command]
+        print('$', ' '.join(command))
         p = subprocess.Popen(command, stdout=subprocess.PIPE,
                              stderr=subprocess.STDOUT)
         stdout, stderr = p.communicate()
         rc = p.wait()
+        if stdout:
+            print(
+                stdout if isinstance(stdout, str) else
+                stdout.decode('ascii', 'backslashreplace')
+            )
         if rc:
-            print(' '.join(command))
-            print(stdout)
             raise subprocess.CalledProcessError(rc, command[0], output=stdout)
 
 
@@ -1350,27 +1400,33 @@ class TestCheckManifest(unittest.TestCase):
     def test_all_is_well(self):
         from check_manifest import check_manifest
         self._create_repo_with_code()
-        self.assertTrue(check_manifest())
+        self.assertTrue(check_manifest(), sys.stderr.getvalue())
 
     def test_relative_pathname(self):
         from check_manifest import check_manifest
         subdir = self._create_repo_with_code_in_subdir()
-        self.assertTrue(check_manifest(subdir))
+        self.assertTrue(check_manifest(subdir), sys.stderr.getvalue())
 
     def test_relative_python(self):
         # https://github.com/mgedmin/check-manifest/issues/36
         from check_manifest import check_manifest
         subdir = self._create_repo_with_code_in_subdir()
         python = os.path.relpath(sys.executable)
-        self.assertTrue(check_manifest(subdir, python=python))
+        self.assertTrue(check_manifest(subdir, python=python),
+                        sys.stderr.getvalue())
 
     def test_python_from_path(self):
         # https://github.com/mgedmin/check-manifest/issues/57
-        # NB: this test assumes you have a 'python' executable somewhere
-        # in your path.
         from check_manifest import check_manifest
+        # We need a Python interpeter to be in PATH.
+        python = 'python'
+        if hasattr(shutil, 'which'):
+            for python in 'python', 'python3', os.path.basename(sys.executable):
+                if shutil.which(python):
+                    break
         subdir = self._create_repo_with_code_in_subdir()
-        self.assertTrue(check_manifest(subdir, python='python'))
+        self.assertTrue(check_manifest(subdir, python=python),
+                        sys.stderr.getvalue())
 
     def test_suggestions(self):
         from check_manifest import check_manifest
